<?php
/**
* Admin page output
*/
class Pm_Tailored_Image_Admin_Page
{
	private $options;
	private $plugin_slug;
	private $plugin_version;
	
	function __construct( $plugin_slug, $plugin_version )
	{
		$this->shared_options = get_option( '_pm_pluginmill_shared' );
		$this->opts = new Pm_Tailored_Image_Options(array());
		$this->custom_imgs = $this->opts->get('pm_tailored_image_custom')->options;
		$this->plugin_slug = $plugin_slug;
		$this->plugin_version = $plugin_version;
		$this->load_dependencies();
		$this->admin = new Pm_Tailored_Image_Admin( $this->plugin_slug, $this->plugin_version );
	}

	private function load_dependencies() {
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-create-frame.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-make.php';
	}

	/*
	 * Add admin page to the menu
	 */
	public function addOptionsPage() {
		$settings = add_options_page(
			__('Tailored Image Settings', 'pm-tailored-image'),
			__('Tailored Image', 'pm-tailored-image'),
			'edit_posts',
			'pm_tailored_image',
			array($this, 'render')
		);
		// Load admin scripts when above page is called
  		add_action( 'load-'.$settings, array( $this->admin, 'enqueue_styles' ) );
  		add_action( 'load-'.$settings, array( $this->admin, 'enqueue_scripts' ) );
	}

	/*
	 * Render admin pages
	 */
	public function render() {
		$tab = ( isset( $_GET['tab'] )  ? $_GET['tab'] : 'personalimg' );
		$settings_section = 'pm_tailored_image_'.$tab.'_tab';
		?>
		<div class="wrap pm-tailored-image">
			<h2><?php _e('Tailored Image Settings', 'pm-tailored-image'); ?></h2>
			<?php $this->render_page_tabs(); ?>
			<form action="options.php" method="POST">
				<?php
				settings_fields( 'pm_tailored_image_opts' );				
				do_settings_sections( $settings_section );
				submit_button( 'Save Changes', 'primary', 'pm_tailored_image_opts[submit-'.$tab.']', false, array( 'id' => 'submit-'.$tab ) );
				?>
			</form>
		</div>
		<?php
	}

	/*
	 * Render Tabs
	 */
	public function render_page_tabs( $current = 'personalimg' ) {
		// Determine which tab to display
		if( isset( $_GET['tab'] ) ) :
			$current = $_GET['tab'];
		else:
			$current = 'personalimg';
		endif;

		// Get list of tabs
		$tabs = $this->define_page_tabs();
		$links = array();

		// Create links for each tab
		foreach ($tabs as $tab => $name) :
			if( $tab == $current ) :
				$links[] = '<a class="nav-tab nav-tab-active" href="?page=pm_tailored_image&tab='.$tab.'">'.$name.'</a>';
			else :
				$links[] = '<a class="nav-tab" href="?page=pm_tailored_image&tab='.$tab.'">'.$name.'</a>';
			endif;
		endforeach;

		echo '<h2 class="nav-tab-wrapper">';
		foreach ( $links as $link ) {
			echo $link;
		}
		echo '</h2>';
	}

	/*
	 * Define Tabs
	 */
	public function define_page_tabs() {
		$tabs = array(
			'personalimg' => __('Personalized Image', 'pm-tailored-image'),
			//'countimg' => __('Countdown Image', 'pm-tailored-image'),
			//'license' => __('License', 'pm-tailored-image'),
			);
		return $tabs;
	}

	/**
	 * Configure the options page using Settings API
	 */
	public function configure() {
		// Register setting
		register_setting( 'pm_tailored_image_opts', 'pm_tailored_image_opts', array($this, 'sanitize') );

		// Sections
		add_settings_section( 'pm_tailored_image_setup',
			__('Create Your Images', 'pm-tailored-image'),
			array($this, 'renderImgSetupSection'),
			'pm_tailored_image_personalimg_tab' );
		add_settings_section(
			'license_section',
			__('Plugin Mill Support License', 'pm-tailored-image'),
			array($this, 'renderLicenseSection'),
			'pm_tailored_image_license_tab'
			);

		// Fields
		add_settings_field(
			'pm_tailored_image_support_key',
			__('Plugin Mill Support Key', 'pm-tailored-image'),
			array($this, 'renderLicenseKeyField'),
			'pm_tailored_image_license_tab',
			'license_section',
			array('name' => 'support')
		);
	}

	/*
	 * Render Sections
	 */
	public function renderImgSetupSection() {
		$this->renderImgSetupForm();
	}
	public function renderLicenseSection() {
		echo "<p>License Key Section</p>";
	}

	/*
	 * Render fields
	 */
	private function renderImgSetupForm(){
		//echo "<pre>".print_r($this->custom_imgs, true)."</pre>";
		?>
		<div class="pm-tailored-image-grid">
			<ul id="image-list">
				<li id="pm-tailored-image-newimg"><span class="dashicons dashicons-plus"></span></li>
				<?php
				if( !empty( $this->custom_imgs ) ) {
				foreach ($this->custom_imgs as $k => $v) {
					?>
					<li id="img-id-<?php echo $k; ?>">
					<div class="img-container">
						<div class="img-preview" data-imgid="<?php echo $k; ?>" style="background-image: url('<?php echo esc_url( $v['preview_img_url'] ); ?>');">
							<div class="edit-img">
								<span class="edit" data-imgid="<?php echo $k; ?>"><span class="dashicons dashicons-edit"></span> Edit</span>
								<span class="delete" data-imgid="<?php echo $k; ?>"><span class="dashicons dashicons-no-alt"></span> Delete</span>
								<p>Image key: <?php echo $k; ?></p>
							</div>
						</div>
					</div>
					</li>
					<?php
				} }
				?>
			</ul>
		</div>
		<?php
	}

	public function renderLicenseKeyField( $args ) {
		$support = ($this->shared_options) ? $this->shared_options['support']: array() ;
		$key_value = ( empty( $support['key'] ) ) ? '' : esc_attr( $support['key'] ) ;
		$input_class = ( empty( $key_value ) ) ? 'pm-support-key-show' : 'pm-support-key-hide' ;
		//echo "<pre>".print_r($this->shared_options, true)."</pre>";
		?>
		<input type="text" id="pm-tailored-image-support-key" class="regular-text <?php echo $input_class; ?>" name="pm_tailored_image_opts[support_key]" value="" >
		<?php
		if( !empty( $support['activation_code'] ) ) {
			if( $support['activation_code'] != 'ok' ) {
				echo $support['activation_message'].'. '.__('De-activate from other sites before activating on this site.', 'pm-pixel-wonder');
			} else {
				?>
				<p class="pm-tailored-image-key-message">Your license is <span class="pm-tailored-image-key-active">ACTIVE!</span></p>
				<button id="pm-tailored-image-reenter-key" class="button button-primary">Enter/Re-enter Key</button>
				<button id="deactivate-key" class="button secondary-button">De-activate Key</button>
				<div id="deactivate-response"></div>
				<?php
			}
		}
	}

	/*
	 * Frame footer
	 */
	public function footer_frame() {
		$render_frame = new Pm_Tailored_Image_Create_Dialog(array());
		$render_frame->personalize_new(array());
		$render_frame->personalize_edit(array());
	}

	/*
	 * Create Preview
	 */
	public function preview_image() {
		//echo "<pre>".print_r($_POST, true)."</pre>";
		// Sanitize
		$options['img_url'] = ( isset( $_POST['img_url'] ) ) ? esc_url_raw( $_POST['img_url'] ) : '' ;
		$options['line1'] = ( isset( $_POST['line1'] ) ) ? stripslashes( $_POST['line1'] ) : '' ;
		$options['line2'] = ( isset( $_POST['line2'] ) ) ? stripslashes( $_POST['line2'] ) : '' ;
		$options['line3'] = ( isset( $_POST['line3'] ) ) ? stripslashes( $_POST['line3'] ) : '' ;
		$options['line4'] = ( isset( $_POST['line4'] ) ) ? stripslashes( $_POST['line4'] ) : '' ;
		$options['view'] = ( isset( $_POST['view'] ) ) ? 1 : 0 ;
		$options['font_size'] = ( empty( $_POST['font_size'] ) ) ? '20' : sanitize_text_field( $_POST['font_size'] ) ;
		$options['font_color'] = ( empty( $_POST['font_color'] ) ) ? '#ff0000' : sanitize_text_field( $_POST['font_color'] ) ;
		$options['text_halign'] = ( isset( $_POST['text_halign'] ) ) ? sanitize_text_field( $_POST['text_halign'] ) : 'left' ;
		$options['text_valign'] = ( isset( $_POST['text_valign'] ) ) ? sanitize_text_field( $_POST['text_valign'] ) : 'top' ;
		$options['font_type'] = ( isset( $_POST['font_type'] ) ) ? sanitize_text_field( $_POST['font_type'] ) : 'PermanentMarker' ;
		$preview = new Pm_Tailored_Image_Make( $options );
		echo $preview->image();
		//echo "<pre>".print_r($options, true)."</pre>";
		
		wp_die();
	}

	/*
	 * Save image & edit or create new
	 */
	public function save_image() {
		// Count array
		if( empty($this->custom_imgs) ) {
			$img_key = 1;
		} else {
			//http://stackoverflow.com/a/2348213/895709
			end($this->custom_imgs);
			$img_key = key($this->custom_imgs);
			$img_key = ++$img_key;
		}
		// Sanitize
		$options['img_key'] = ( isset( $_POST['img_key'] ) ) ? sanitize_key( $_POST['img_key'] ) : $img_key ; 
		$options['img_url'] = ( isset( $_POST['img_url'] ) ) ? esc_url_raw( $_POST['img_url'] ) : '' ;
		$options['preview_img_url'] = ( isset( $_POST['preview_img_url'] ) ) ? esc_url_raw( $_POST['preview_img_url'] ) : '' ;
		$options['line1'] = ( isset( $_POST['line1'] ) ) ? stripslashes( $_POST['line1'] ) : '' ;
		$options['line2'] = ( isset( $_POST['line2'] ) ) ? stripslashes( $_POST['line2'] ) : '' ;
		$options['line3'] = ( isset( $_POST['line3'] ) ) ? stripslashes( $_POST['line3'] ) : '' ;
		$options['line4'] = ( isset( $_POST['line4'] ) ) ? stripslashes( $_POST['line4'] ) : '' ;
		$options['default_name'] = ( isset( $_POST['default_name'] ) ) ? sanitize_text_field( $_POST['default_name'] ) : '' ;
		$options['view'] = ( empty( $_POST['view'] ) ) ? 0 : 1 ;
		$options['font_size'] = ( empty( $_POST['font_size'] ) ) ? '20' : sanitize_text_field( $_POST['font_size'] ) ;
		$options['font_color'] = ( empty( $_POST['font_color'] ) ) ? '#ff0000' : sanitize_text_field( $_POST['font_color'] ) ;
		$options['text_halign'] = ( isset( $_POST['text_halign'] ) ) ? sanitize_text_field( $_POST['text_halign'] ) : 'left' ;
		$options['text_valign'] = ( isset( $_POST['text_valign'] ) ) ? sanitize_text_field( $_POST['text_valign'] ) : 'top' ;
		$options['font_type'] = ( isset( $_POST['font_type'] ) ) ? sanitize_text_field( $_POST['font_type'] ) : 'PermanentMarker' ;
		$options['operation'] = ( isset( $_POST['operation'] ) ) ? sanitize_text_field( $_POST['operation'] ) : '' ;
		//echo "<pre>".print_r($options, true)."</pre>";

		/**/
		$make = new Pm_Tailored_Image_Make( $options );
		if( $options['operation'] === 'edit_image' ) {
				$old_preview_img_url = $make->get_full_img_path($options['preview_img_url']);
				unlink($old_preview_img_url);
			}

		echo $make->image();		

		wp_die();
	}

	// Populate Edit Image Dialog
	public function edit_image() {
		// Sanitize
		if( isset( $_POST['mode'] ) && $_POST['mode'] === 'lookup' ) {
			$image_key = ( isset( $_POST['image_key'] ) && is_numeric( $_POST['image_key'] ) ) ? sanitize_key( $_POST['image_key'] ) : '' ;
			
			echo json_encode( $this->custom_imgs[$image_key] );
		}

		wp_die();
	}

	// Delete image
	public function delete_image() {
		// Sanitize
		$options['action'] = ( isset( $_POST['action'] ) && ( $_POST['action'] === 'delete_image' ) ) ? 'delete_image' : '' ;
		$options['img_key'] = ( isset( $_POST['img_key'] ) && is_numeric( $_POST['img_key'] ) ) ? sanitize_key( $_POST['img_key'] ) : NULL ;
		$image = new Pm_Tailored_Image_Make( $options );
		echo $image->delete();
		//print_r($image->delete());
		
		wp_die();
	}

	/*
	 * Sanitize input
	 */
	public function sanitize( $input ) {
		$saved_opts = $this->options;
		/* Not used for saving image settings
		$keys = $saved_opts->get('keys');		
		$now = new DateTime( null, new DateTimeZone('UTC') );
		$reverifyDate = strtotime('+30day', $now->getTimestamp());

		// Figure out which tab is submitted
		$personalimg_tab = ( !empty( $input['submit-personalimg'] ) ? true : false );
		$license_tab = ( !empty( $input['submit-license'] ) ? true : false );

		// Save based on tab
		if( $personalimg_tab ) {
		}
		*/
	}

	/*
	 * Runs the class
	 */
	public function run() {
		add_action( 'admin_init', array($this, 'configure') );
		add_action( 'admin_menu', array($this, 'addOptionsPage') );
		add_action( 'admin_footer-settings_page_pm_tailored_image', array($this, 'footer_frame') );
		add_action( 'wp_ajax_save_image', array($this, 'save_image') );
		add_action( 'wp_ajax_preview_image', array($this, 'preview_image') );
		add_action( 'wp_ajax_delete_image', array($this, 'delete_image') );
		add_action( 'wp_ajax_edit_image', array($this, 'edit_image') );
	}
}