<?php
/**
* Adds button to editor
*/
class Pm_Tailored_Image_Tmce
{
	private $options;

	function __construct( $options )
	{
		$this->options = $options;
		$this->opts = new Pm_Tailored_Image_Options(array());
		$this->custom_imgs = $this->opts->get('pm_tailored_image_custom')->options;
	}

	public function init_tmce_buttons() {
		// Don't bother if current user doesn't have permissions
		if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
	     return;
		
		// Add only in rich editor mode
		if( get_user_option( 'rich_editing' ) == 'true' ) {
			// Global object containing current admin page
    		global $pagenow;
    		if ( 'post.php' === $pagenow || 'post-new.php' === $pagenow ) {
				add_action( 'admin_enqueue_scripts', array( $this, 'tmce_admin_scripts' ) );
				add_filter( 'mce_external_plugins', array( $this, 'add_mce_plugin' ) );
				add_filter( 'mce_buttons', array( $this, 'add_tmce_buttons' ) );
				//add_action( 'before_wp_tiny_mce', array( $this, 'tinymce_localize' ) );
				add_action( 'print_media_templates', array( $this, 'print_media_templates' ) );
				add_action( 'admin_head', array( $this, 'admin_head' ) );
				add_action( 'admin_head', array( $this, 'tinymce_localize' ) );
				add_action( 'mce_css', array( $this, 'mce_css' ) );
			}

		} // End if not the right pages
	}

	public function add_mce_plugin( $plugins ) {
		// this plugin file will work the magic of our button
		$plugins['pmtimgbuttons'] = PM_TIMG_DIR . 'admin/js/shortcode-dialog.js';
			return $plugins;
	}

	public function add_tmce_buttons( $buttons ) {
		array_push( $buttons, '|', 'pmtimgbuttons' );
    	return $buttons;
	}

	public function tinymce_localize() {
		$params = array(
			'plugin_name' => PM_TIMG_PLUGIN_NAME,
			'plugin_url' => PM_TIMG_DIR,
			'site_url' => site_url(),
			'images' => $this->custom_imgs,
			'width_label' => __('W', 'pm-tailored-image'),
			'height_label' => __('H', 'pm-tailored-image'),
			'align_label' => __('Align', 'pm-tailored-image'),
			'align_none_label' => __('None', 'pm-tailored-image'),
			'align_left_label' => __('Align left', 'pm-tailored-image'),
			'align_center_label' => __('Align center', 'pm-tailored-image'),
			'align_right_label' => __('Align right', 'pm-tailored-image'),
			'insert_label' => __('Insert', 'pm-tailored-image')
		);
		?>
		<script type='text/javascript'>
		/* <![CDATA[ */
		var pm_timg_tmce_obj = <?php echo json_encode( $params ); ?>;
		/* ]]> */
		</script>
		<?php
	}

	public function print_media_templates() {
		if( !isset(get_current_screen()->id ) || get_current_screen()->base != 'post' )
			return;

		include_once( dirname( __FILE__ ).'/timg-editor-template.html' );
	}

	public function admin_head() {
		$current_screen = get_current_screen();
		if( !isset( $current_screen->id ) || $current_screen->base !== 'post' ) {
			return;
		}
		wp_enqueue_script( 'pm-timg-template-view', PM_TIMG_DIR.'admin/js/pm-timg-template-view.js', array( 'shortcode', 'wp-util', 'jquery' ), false, true );
	}

	public function tmce_admin_scripts( $hook ) {
		global $post;
		if( $hook == 'post-new.php' || $hook == 'post.php' ) {
			// For TinyMCE
			wp_enqueue_style( 'pm-tailored-image-editor-font', PM_TIMG_DIR.'/admin/css/fontello/css/pmtimg.css' );
		}
	}

	public function mce_css( $mce_css ) {
		if( !empty( $mce_css ) )
			$mce_css .= ',';
		$mce_css .= PM_TIMG_DIR.'/admin/css/style.css';
		return $mce_css;
	}

	public function run() {
		add_action( 'admin_init', array($this, 'init_tmce_buttons') );
	}
}