<html>
	<head>
	<style>
		body {
			font-family: -apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif;
			font-size: 16px;
			line-height: 1.4em;
		}
		#options {
			text-align: center;
		}
		#images li {
			display: inline-block;
			margin: 0 5px 0 0;
			list-style-type: none;
			cursor: pointer;
		}
		#submit-button {
			text-align: center;
		}
		input {
			padding: 0.4em;
			height: 29px;
		}
		select {
			height: 29px;
		}
		button {
			font-size: 13px;
			color: #555;
			background: #f7f7f7;
			box-shadow: 0 1px 0 #ccc;
			vertical-align: top;
			border-color: #ccc;
			border-radius: 3px;
			border-width: 1px;
			height: 28px;
			box-sizing: border-box;
			cursor: pointer;
			padding: 0.2em 2em;
		}
		button:hover {
			background: #fafafa;
			border-color: #999;
			color: #23282d;
		}
		li.selectedimg img {
			box-shadow: 0 1px 0 #0073aa, 0 0 2px 1px #33b3db;
			opacity: 0.5;
		}
		input[name="selectedimg"] {
			display: none;
		}
	</style>
	</head>
	<body>
		<div id="images"></div>
		<div id="options">
			<p>
				<label>
					<span id="width-text">W:</span> <input id="width" type="text">
				</label>
				<label>
					<span id="height-text">H:</span> <input id="height" type="text">
				</label>
				<label>
					<select name="unit" id="unit">
						<option value="%">(%)</option>
						<option value="px">(px)</option>
					</select>
				</label>
			</p>
			<p>
				<label><span id="align-text">Align:</span>
				<select name="align" id="align">
					<option id="align-none" value="none">None</option>
					<option id="align-left" value="alignleft">Align left</option>
					<option id="align-center" value="aligncenter">Align center</option>
					<option id="align-right" value="alignright">Align right</option>
				</select>
				</label>
			</p>
			<p id="submit-button">
				<button id="insert-image">Insert</button>
			</p>
		</div>
		<script type="text/javascript">
			// Pull in jQuery http://stackoverflow.com/a/37605494/895709
			if(typeof(jQuery) == 'undefined') {
				window.jQuery = function(selector) { return parent.jQuery(selector, document);
					jQuery = parent.$.extend(jQuery, parent.$);
					window.$ = jQuery;
				}
			};
			var args = top.tinymce.activeEditor.windowManager.getParams();
			var shortcode_tag = 'pm_tailored_img';
			var images = Object.keys(args.images).map(function(k) {return args.images[k]});
			for(i=0;i<images.length;i++) {
				show_image(images[i].preview_img_url, images[i].img_key);
			}

			jQuery(document).ready( function($){
				// Use i18n text
				console.log(JSON.stringify(args, null, 4));
				jQuery('#width-text').text(args.width_label);
				jQuery('#height-text').text(args.height_label);
				jQuery('#align-text').text(args.align_label);
				jQuery('#align-none').text(args.align_none_label);
				jQuery('#align-left').text(args.align_left_label);
				jQuery('#align-center').text(args.align_center_label);
				jQuery('#align-right').text(args.align_right_label);
				jQuery('#insert-image').text(args.insert_label);

				// Fill form with data if any
				if( args.curr_img_key != null ) {
					jQuery("input[name=selectedimg][value="+args.curr_img_key+"]").prop('checked', true);
					jQuery("img#"+args.curr_img_key).parent().parent().addClass('selectedimg');
				}
				if( args.curr_width != null ) {
					jQuery("#width").val(args.curr_width);
				}
				if( args.curr_height != null ) {
					jQuery("#height").val(args.curr_height);
				}
				if( args.curr_unit != null ) {
					jQuery("#unit").val(args.curr_unit);
				}
				if( args.curr_align != null ) {
					jQuery("#align").val(args.curr_align);
				}

				jQuery(document).on('click', '#images li', function(e) {
					jQuery(this).addClass('selectedimg').siblings().removeClass('selectedimg');
				});

				jQuery('#insert-image').on('click', function() {
					var selectedimg = jQuery('input[name=selectedimg]:checked').val();
					var width = (jQuery('#width').val() == '') ? '' : jQuery('#width').val() ;
					var height = (jQuery('#height').val() == '') ? '' : jQuery('#height').val() ;
					var unit = jQuery('#unit').val();
					var align = jQuery('#align').val();
					generate_shortcode(selectedimg, width, height, unit, align);
				});
			}); // global end
			

			//http://stackoverflow.com/a/5454306/895709
			//http://stackoverflow.com/a/21422401/895709
			function show_image(src, img_id) {
				var li = document.createElement("li");
				var img = document.createElement("img");
				var label = document.createElement("label");
				var input = document.createElement("input");
				input.type = 'radio';
				input.name = 'selectedimg';
				input.value = img_id;
				img.id = img_id;
				img.src = src;
				img.width = '80';
				img.height = '80';
				img.setAttribute('data-img_id', img_id);

				// This next line will just add it to the <body> tag
				document.getElementById('images').appendChild(li).appendChild(label).appendChild(img).insertAdjacentElement('afterend', input);
			}

			function generate_shortcode(img_id, width, height, unit, align) {
				var shortcode_str = '['+shortcode_tag+' img_key="'+img_id+'" width="'+width+'" height="'+height+'" unit="'+unit+'" align="'+align+'"]';
				top.tinymce.activeEditor.execCommand('mceInsertContent', false, shortcode_str);
				top.tinymce.activeEditor.windowManager.close();
			}
		</script>
	</body>
</html>