jQuery(document).ready( function($){
	// Create a modal view.
	var modal = new wp.media.view.Modal({
		// A controller object is expected
		controller: { trigger: function() {} }
	});
	// Create a modal content view.
	var ModalContentView = wp.Backbone.View.extend({
		className: 'pm-tailored-img-modal-content',
		template: wp.template( 'pm-tailored-img-modal-content' )
	});
	var ModalEditView = wp.Backbone.View.extend({
		className: 'pm-tailored-img-edit-modal',
		template: wp.template( 'pm-tailored-img-edit-modal' )
	});

	// When the user clicks a button, open a modal.
	$('#pm-tailored-image-newimg').click( function( event ) {
		event.preventDefault();
		// Assign the ModalContentView to the modal as the `content` subview.
		// Proxies to View.views.set( '.media-modal-content', content );
		modal.content( new ModalContentView() );
		// Out of the box, the modal is closed, so we need to open() it.
		modal.open();
		/* Color Picker */
		$('.color-picker').wpColorPicker({
			palettes: false,
			change: function(event, ui) {
				pm_tailored_generate_preview_img();
			}
		});
	});
	$(document).on('click', '.edit', function(e) {
		//
		modal.content( new ModalEditView() );
		modal.open();
		var img_key = $(this).data('imgid');

		// Lookup image
		var imgdata = {
			'action': 'edit_image',
			'mode': 'lookup',
			'image_key': img_key
		}
		$.post(ajaxurl, imgdata, function(response) {
			var imgdata = JSON.parse(response);
			$('.edit-tailored-img').attr("data-imageid", img_key);
			$('#new-personalized-img').val(imgdata.img_url);
			$('#view-personalized-img').attr('src', imgdata.preview_img_url);
			$('#preview-img-url').val(imgdata.preview_img_url);
			$('#pm-tailored-line1').val(imgdata.line1);
			$('#pm-tailored-line2').val(imgdata.line2);
			$('#pm-tailored-line3').val(imgdata.line3);
			$('#pm-tailored-line4').val(imgdata.line4);
			$('#pm-tailored-default-name').val(imgdata.default_name);
			$('#pm-tailored-font-size').val(imgdata.font_size);
			$('#pm-tailored-font-color').val(imgdata.font_color);
			$("input[name=texthalign][value="+imgdata.text_halign+"]").prop('checked', true);
			$("input[name=textvalign][value="+imgdata.text_valign+"]").prop('checked', true);
			$("input[name=fonttype][value="+imgdata.font_type+"]").prop('checked', true);
			$('.color-picker').wpColorPicker({
				defaultColor: imgdata.font_color,
				palettes: false,
				change: function(event, ui) {
					pm_tailored_generate_preview_img();
				}
			});
		});
	});

	// Image selector/uploader
	$(document).on('click', '.choose-tailored-img', function() {
		var frame = new wp.media.view.MediaFrame.Select({
			multiple: false,
			title: pm_timg_set_scrn_obj.select_image_label,
			button: {
				text: pm_timg_set_scrn_obj.set_image_label
			},
			library: {
				type: 'image/jpeg'
			}
		});
		frame.on('select', function() {
			var selection = frame.state().get('selection').first().toJSON();
			$('#view-personalized-img').attr('src', selection.url);
			$('#new-personalized-img').val(selection.url);
			$('#new-personalized-img').removeClass('error');
			$('div.error').remove();
			pm_tailored_is_jpg( selection.url );
		});
		frame.open();
	});

	// Preview image
	$(document).on('change focus', '#pm-tailored-img-text input, #pm-tailored-font-size, #pm-tailored-font-color, a.wp-color-result, label.textvalign, label.texthalign, label.fonttype', function(e) {
		pm_tailored_img_entered();
		pm_tailored_generate_preview_img();
	});

	// Save new or edit image
	$(document).on('click', '#create-new-img, #edit-tailored-img', function(e) {
		e.preventDefault();

		if(this.className.includes('edit-tailored-img')) {
			var operation = 'edit_image';
		} else {
			var operation = 'save_image'
		}
		if( operation == 'edit_image' ) {
			preview_img_url = $('#preview-img-url').val();
		} else {
			preview_img_url = '';
		}
		var imgid = $('.edit-tailored-img').data('imageid');

		var data = {
			'action': 'save_image',
			'img_key' : imgid,
			'img_url': $('#new-personalized-img').val(),
			'preview_img_url' : preview_img_url,
			'line1': $('#pm-tailored-line1').val(),
			'line2': $('#pm-tailored-line2').val(),
			'line3': $('#pm-tailored-line3').val(),
			'line4': $('#pm-tailored-line4').val(),
			'default_name': $('#pm-tailored-default-name').val(),
			'view': 0,
			'font_size': $('#pm-tailored-font-size').val(),
			'font_color': $('#pm-tailored-font-color').val(),
			'text_halign': $('input[name=texthalign]:checked').val(),
			'text_valign': $('input[name=textvalign]:checked').val(),
			'font_type': $('input[name=fonttype]:checked').val(),
			'operation' : operation
		}
		/**/
		$.post(ajaxurl, data, function(response) {
			$('li#img-id-'+imgid).html('<div class="pm-tailored-loading">'+pm_timg_set_scrn_obj.please_wait_label+'</div>');
			//$('#image-list').append(response);
			location.reload(true);
		});
		//console.log(operation +' '+JSON.stringify(data, null, 4));
		modal.close();
	});

	// Delete image
	$(document).on('click', '.delete', function(e) {
		var img_key = $(this).data('imgid');		
		var data = {
			'action': 'delete_image',
			'img_key': img_key
		}
		
		$.post(ajaxurl, data, function(response) {
			//Remove li
			$('#img-id-'+img_key).remove();
			$('.pm-tailored-image-grid').append(response);
		});
	});

	// Image exists check
	function pm_tailored_img_entered(){
		if( !$('#new-personalized-img').val() ) {
			$('div.error').remove();
			$('#new-personalized-img').addClass('error');
			$('#new-personalized-img').after('<div class="error">'+pm_timg_set_scrn_obj.field_cannot_be_empty_label+'</div>');
			return false;
		}
	}

	// Check for jpg only
	function pm_tailored_is_jpg(file_url) {
		var ext = file_url.split('.').pop().toLowerCase();
		if( !(ext == 'jpg' || ext == 'jpeg') ) {
			$('#new-personalized-img').addClass('error');
			$('#new-personalized-img').after('<div class="error">'+pm_timg_set_scrn_obj.warning_not_jpg_label+'</div>')
			return;
		}
	}

	// Generate preview image
	function pm_tailored_generate_preview_img() {
		var data = {
			'action': 'preview_image',
			'img_url': $('#new-personalized-img').val(),
			'line1': $('#pm-tailored-line1').val(),
			'line2': $('#pm-tailored-line2').val(),
			'line3': $('#pm-tailored-line3').val(),
			'line4': $('#pm-tailored-line4').val(),
			'default_name': $('#pm-tailored-default-name').val(),
			'view': 1,
			'font_size': $('#pm-tailored-font-size').val(),
			'font_color': $('#pm-tailored-font-color').val(),
			'text_halign': $('input[name=texthalign]:checked').val(),
			'text_valign': $('input[name=textvalign]:checked').val(),
			'font_type': $('input[name=fonttype]:checked').val()
		}
		$.post(ajaxurl, data, function(response) {
			$('#view-personalized-img').attr('src', response);
		});
		//console.log('Image data'+JSON.stringify(data, null, 4));
	}
}); // global end