<?php
/**
* Creates custom image
*/
class Pm_Tailored_Image_Make
{
	private $options;

	function __construct( $options )
	{
		$this->options = $options;
		$this->opts = new Pm_Tailored_Image_Options(array());
		$this->saved_opts = $this->opts->get('pm_tailored_image_custom')->options;
	}

	public function image() {
		return $this->build_image( $this->options );
	}

	public function delete() {
		// Get preview path then unlink
		$img_array = $this->saved_opts[$this->options['img_key']];
		$preview_img_path = $this->get_full_img_path($img_array['preview_img_url']);
		unlink( $preview_img_path );
		// Remove image info from array
		unset( $this->saved_opts[$this->options['img_key']]);
		$set = $this->opts->set('pm_tailored_image_custom', $this->saved_opts);
	}

	private function build_image( $args ) {
		$bgimg = $this->get_full_img_path($args['img_url']);
		$bgimg_path = pathinfo($bgimg);
		$filename = $bgimg_path['filename'];
		$extension = $bgimg_path['extension'];
		$font = PM_TIMG_PATH.'public/fonts/'.$args['font_type'].'.ttf';
		$uniqid = uniqid();
		$message = "$args[line1]\n$args[line2]\n$args[line3]\n$args[line4]";

		if( ($extension == 'jpg') || ($extension == 'jpeg') ) {
			$bgimg = imagecreatefromjpeg($bgimg);
		}
		if( $extension == 'gif' ) {
			$bgimg = imagecreatefromgif($bgimg);
		}
		if( $extension == 'png' ) {
			$bgimg = imagecreatefrompng($bgimg);
		}

		$tb = imagettfbbox($args['font_size'], 0, $font, $message);
		$imgSize = getimagesize( $args['img_url'] );
		//$x = ceil( ( $imgSize[0] - $tb[2] ) / 2 );
		if( $args['text_valign'] == 'top' ) {
			$y = ceil( ($imgSize[1] - $tb[3]) * 0.15 );
		} elseif( $args['text_valign'] == 'bottom' ) {
			$y = ceil( ( $imgSize[1] - $tb[3] )* 0.9 );
		} else {
			$y =  ceil( ($imgSize[1] - $tb[3])  / 2 );
		}
		if( $args['text_halign'] == 'center') {
			$x = ceil( ( $imgSize[0] - $tb[2] ) / 2 );
		} elseif ( $args['text_halign'] == 'right' ) {
			$x = ceil( $imgSize[0] - ( $tb[2] + 10 ) );
		} else {
			$x = 10;			
		}
		$tColor = $this->hex2rgb($args['font_color']);
		$textColor = imagecolorallocate($bgimg, $tColor[0], $tColor[1], $tColor[2]);

		// Create text image
		imagettftext($bgimg, $args['font_size'], '0', $x, $y, $textColor, $font, $message);

		// Save temp img
		ob_start();
		if( ($extension == 'jpg') || ($extension == 'jpeg') ) {
			if( $args['view'] === 1 ) {
				imagejpeg($bgimg);
			} else {
				imagejpeg($bgimg, PM_TIMG_PATH.'public/tmp/'.$uniqid.'-'.$filename.'.jpg');
			}
		}
		if( $extension == 'gif' ) {
			if( $args['view'] === 1 ) {
				imagepng($bgimg);
			} else {
				imagepng($bgimg, PM_TIMG_PATH.'public/tmp/'.$uniqid.'-'.$filename.'.png');
			}
			$extension = 'png';
		}
		if( $extension == 'png' ) {
			if( $args['view'] === 1 ) {
				imagepng($bgimg);
			} else {
				imagepng($bgimg, PM_TIMG_PATH.'public/tmp/'.$uniqid.'-'.$filename.'.png');
			}
		}
		
		imagedestroy($bgimg);
		if( $args['view'] === 1 ) {
			$result_image = ob_get_clean();
			return 'data:image/'.$extension.';base64,'.base64_encode($result_image);
			//return $imgSize[1].', '.$tb[3].', '.$y.', '.$args['text_valign'];
		} else {
			$new_preview_img_url = PM_TIMG_DIR.'public/tmp/'.$uniqid.'-'.$filename.'.'.$extension;
			// Build options array to save
			$args['preview_img_url'] = $new_preview_img_url;
			// If image editing, use image key
			if( $args['operation'] === 'edit_image' ) {
				$this->saved_opts[$args['img_key']] = $args;
			} else {
				// Set the array to start a 1
				if( empty($this->saved_opts) ) {
					$this->saved_opts[1] = $args;
				} else {
					$this->saved_opts[] = $args;
				}
			}
			
			// Save to options
			$this->opts->set( 'pm_tailored_image_custom', $this->saved_opts );
			?>
			<li>
				<div class="img-container">
					<div class="img-preview" style="background-image: url('<?php echo $preview_img_url; ?>');"></div>
					<div class="edit-img">Edit</div>
				</div>
			</li>
			<?php
		}		
	}

	public function get_full_img_path( $file ) {
		// Determine WP path
		$parse_site_url = parse_url( get_site_url() );
		$site_folder = ( isset($parse_site_url['path']) ) ? $parse_site_url['path'] : '' ;
		$site_path = ( empty( $site_folder ) ) ? dirname(WP_CONTENT_DIR) : dirname(dirname(WP_CONTENT_DIR));
		$parse_file_url = parse_url( $file );
		$img_path = $parse_file_url['path'];

		// Build image path
		return $site_path.$img_path;
	}

	private function hex2rgb($hex) {
	   $hex = str_replace("#", "", $hex);

	   if(strlen($hex) == 3) {
	      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
	      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
	      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
	   } else {
	      $r = hexdec(substr($hex,0,2));
	      $g = hexdec(substr($hex,2,2));
	      $b = hexdec(substr($hex,4,2));
	   }
	   $rgb = array($r, $g, $b);
	   //return implode(",", $rgb); // returns the rgb values separated by commas
	   return $rgb; // returns an array with the rgb values
	}
}